out_of_line_image.pdf

## Metadata

Title | out_of_line_image.pdf
Path | C:\Users\jenni\OneDrive\Documents\Code\burdoc\burdoc\tests\integration\data\inputs\out_of_line_image.pdf
Pages | 0
PDF Metadata: format | PDF 1.7
PDF Metadata: title |
PDF Metadata: author | Joe Ennis
PDF Metadata: subject |
PDF Metadata: keywords |
PDF Metadata: creator | Microsoft® Word for Microsoft 365
PDF Metadata: producer | Microsoft® Word for Microsoft 365
PDF Metadata: creationDate | D:20230403060754+01'00'
PDF Metadata: modDate | D:20230403060754+01'00'
PDF Metadata: trapped |
PDF Metadata: encryption |

## Contents

1. Page 0

#### Page 0

Path: | content.0.[4,4].bbox
Type: | addition

Key | Old | New
x1 |  | 284.3299865722656
y1 |  | 721.707275390625
y0 |  | 601.8273315429688
x0 |  | 72.02400207519531

Path: | content.0.[1,1].bbox
Type: | addition

Key | Old | New
x1 |  | 170.4199981689453
y1 |  | 463.6772766113281
y0 |  | 208.74729919433594
x0 |  | 72.02400207519531

Path: | content.0.[2,2].bbox
Type: | addition

Key | Old | New
x1 |  | 276.6599426269531
y1 |  | 558.71728515625
y0 |  | 479.2772521972656
x0 |  | 72.02400207519531

Path: | content.0.[3,3].bbox
Type: | addition

Key | Old | New
x1 |  | 413.6499938964844
y1 |  | 529.8499755859375
y0 |  | 212.54998779296875
x0 |  | 175.75

Path: | content.0.[5,5].bbox
Type: | addition

Key | Old | New
x1 |  | 280.8600158691406
y1 |  | 762.7672729492188
y0 |  | 737.3272705078125
x0 |  | 72.02400207519531

Path: | content.0.[6,6].bbox
Type: | addition

Key | Old | New
x1 |  | 519.196044921875
y1 |  | 587.1873168945312
y0 |  | 561.7472534179688
x0 |  | 315.42999267578125

Path: | content.0.[7,7].bbox
Type: | addition

Key | Old | New
x1 |  | 521.2059936523438
y1 |  | 152.70726013183594
y0 |  | 73.26725006103516
x0 |  | 315.42999267578125

Path: | content.0.[8,8].bbox
Type: | addition

Key | Old | New
x1 |  | 511.6779479980469
y1 |  | 234.1873016357422
y0 |  | 168.1873016357422
x0 |  | 315.42999267578125

Path: | content.0.[9,9].bbox
Type: | addition

Key | Old | New
x1 |  | 525.3460693359375
y1 |  | 518.7572631835938
y0 |  | 277.2972717285156
x0 |  | 421.75

Lorem ipsum dolor sit amet. 33 distinctio expedita ut recusandae unde sit voluptas perspiciatis ab voluptatem sequi? Eum dignissimos dignissimos et optio rerum eum neque rerum! Est vitae harum ab vitae voluptatem qui iure quia rem voluptas consequatur non corrupti adipisci. Sit pariatur aliquam non iure ducimus est autem dolorem aut ipsum unde qui corrupti labore.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

Nam distinctio voluptatem At saepe nulla quo fuga autem. Et dicta natus eos rerum dolor ab nemo voluptas ex autem dignissimos ut temporibus dicta.

Lorem ipsum dolor sit amet. 33 distinctio expedita ut recusandae unde sit voluptas perspiciatis ab voluptatem sequi? Eum dignissimos dignissimos et optio rerum eum neque rerum! Est vitae harum ab vitae voluptatem qui iure quia rem voluptas consequatur non corrupti adipisci. Sit pariatur aliquam non iure ducimus est autem dolorem aut ipsum unde qui corrupti labore.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit

"Old document" by storebukkebruse is licensed under CC BY 2.0.

recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

Nam distinctio voluptatem At saepe nulla quo fuga autem. Et dicta natus eos rerum dolor ab nemo voluptas ex autem dignissimos ut temporibus dicta.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

Lorem ipsum dolor sit amet. 33 distinctio expedita ut recusandae unde sit voluptas perspiciatis ab voluptatem sequi? Eum dignissimos dignissimos et optio rerum eum neque rerum! Est vitae harum ab vitae voluptatem qui iure quia rem voluptas consequatur non corrupti adipisci. Sit pariatur aliquam non iure ducimus est autem dolorem aut ipsum unde qui corrupti labore.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

Nam distinctio voluptatem At saepe nulla quo fuga autem. Et dicta natus eos rerum dolor ab nemo voluptas ex autem dignissimos ut temporibus dicta.

Lorem ipsum dolor sit amet. 33 distinctio expedita ut recusandae unde sit voluptas perspiciatis ab voluptatem sequi? Eum dignissimos dignissimos et optio rerum eum neque rerum! Est vitae harum ab vitae voluptatem qui iure quia rem voluptas consequatur non corrupti adipisci. Sit pariatur aliquam non iure ducimus est autem dolorem aut ipsum unde qui corrupti labore.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit

"Old document" by storebukkebruse is licensed under CC BY 2.0.

recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

Nam distinctio voluptatem At saepe nulla quo fuga autem. Et dicta natus eos rerum dolor ab nemo voluptas ex autem dignissimos ut temporibus dicta.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

Parent File Contents